#include <SPI.h>
#include <NRFLite.h>
NRFLite _radio;

struct RadioPacket
{
  uint8_t row[3];
	uint16_t pot[4];
};

RadioPacket _radioData;

int nrfID = 22;
int CEPin = 10;
int CSNPin = 9;

const byte ROWS = 3; //rows
const byte COLS = 8; //columns

byte rowPins[ROWS] = {19, 18, 8}; //connect to the row pinouts of the matrix 19=A5, 18=A4
byte colPins[COLS] = {7, 6, 5, 4, 3, 2, 1, 0}; //connect to the column pinouts of the matrix

void pin_mode(byte pinNum, byte mode) { pinMode(pinNum, mode); }
void pin_write(byte pinNum, boolean level) { digitalWrite(pinNum, level); }
int  pin_read(byte pinNum) { return digitalRead(pinNum); }

//**** 
// Code derrived from Keypad library by Mark Stanley https://github.com/Nullkraft/Keypad
// Because we only need the binary status of the pins and do not care about a character on the keypad
// that is pressed, this extract from the library is perfect...

void scanKeys() {
	// Re-intialize the row pins. Allows sharing these pins with other hardware.
	for (byte r=0; r<ROWS; r++) {
		pin_mode(rowPins[r],INPUT_PULLUP);
	}

	// RadioData.row stores ALL the keys that are being pressed.
	for (byte c=0; c<COLS; c++) {
		pin_mode(colPins[c],OUTPUT);
		pin_write(colPins[c], LOW);	// Begin column pulse output.
		for (byte r=0; r<ROWS; r++) {
			bitWrite(_radioData.row[r], c, !pin_read(rowPins[r]));  // keypress is active low so invert to high.
		}
		// Set pin to high impedance input. Effectively ends column pulse.
		pin_write(colPins[c],HIGH);
		pin_mode(colPins[c],INPUT);
	}
}
// ****

void setup(){
    pinMode(A0, INPUT);
    pinMode(A1, INPUT);
    pinMode(A2, INPUT);
    pinMode(A3, INPUT);
    _radio.init(nrfID, CEPin, CSNPin); // Set transmitter radio to Id, along with the CE and CSN pins
}

void loop() {
  for (int i=0;i<4;i++){  // Read the analog inputs and add to the array)
	  _radioData.pot[i] = analogRead(i+14);
	}
	scanKeys();  //Get the status of the buttons...
  _radio.send(1, &_radioData, sizeof(_radioData), NRFLite::NO_ACK); // Send to the radio with Id = 1, no ACK
}
